<?php
/**
 * ダイアル特典テンプレート
 * theme-option.php
 */

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

function theme_options_init(){
	register_setting( 'winp_options', 'winp_theme_options', 'theme_options_validate' );
}
function theme_options_add_page() {
	add_menu_page( __( 'Setting Template', 'winpresstheme' ), __( 'テンプレート設定', 'winpresstheme' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );
}

/**
 * theme_options_do_page
 * テーマオプションの選択項目を生成
 */

function theme_options_do_page() {
	// テーマベースカラー
	$theme_color = array(
		'black' => 'ブラック（デフォルト）',
		'green' => 'グリーン',
		'navy' => 'ネイビー',
		'blue' => 'ブルー',
		'red' => 'レッド',
		'pink' => 'ピンク'
	);

	// サイトレイアウト
	$column_position = array(
		'right' => '2カラム（右サイドバー）',
		'left' => '2カラム（左サイドバー）',
		'none' => '1カラム'
	);

	// ヘッダー画像表示
	$header_image_display = array(
		'all' => 'すべてのページに表示する',
		'home' => 'トップページでのみ表示する',
		'none' => '表示しない'
	);

	// タイトルをヘッダーに表示
	$header_title_display = array(
		'all' => '表示する',
		'none' => '表示しない'
	);

	// サイト説明文をヘッダーに表示
	$header_desc_display = array(
		'all' => '表示する',
		'none' => '表示しない'
	);

	// パン屑リスト表示
	$breadcrumb_display = array(
		'all' => '表示する',
		'none' => '表示しない'
	);

	// ヘッダ画像の代わりに「Meta Slider」を利用する 
	$do_meta_slider = array(
		'none' => '利用しない',
		'active' => '利用する'
	);

	// トップページに表示する「投稿」の件数
	$home_post_count = array(
		'none' => '表示しない',
		'1' => '1件',
		'2' => '2件',
		'3' => '3件',
		'4' => '4件',
		'5' => '5件',
		'6' => '6件',
		'7' => '7件',
		'8' => '8件',
		'9' => '9件',
		'10' => '10件'
	);

	// 記事のカテゴリ表示
	$post_cat_display = array(
		'all' => '表示する',
		'none' => '表示しない'
	);

	// 記事の投稿日時表示
	$post_date_display = array(
		'all' => '表示する',
		'none' => '表示しない'
	);

	// 関連記事の表示
	$related_post_display = array(
		'all' => '表示する',
		'none' => '表示しない'
	);

	if ( ! isset( $_REQUEST['settings-updated'] ) ) { $_REQUEST['settings-updated'] = false; }
?>
	<div class="wrap">
		<h2>テンプレート設定</h2>

<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong>設定を保存しました</strong></p></div>
<?php endif; ?>

		<form method="post" action="options.php">
<?php settings_fields( 'winp_options' ); ?>
<?php $options = get_option( 'winp_theme_options' ); ?>

			<h3 class="title">全体設定</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">テーマベースカラー</th>
					<td>
						<select name="winp_theme_options[theme_color]">
<?php foreach ($theme_color as $theme_color_key => $theme_color_val): ?>
<?php if ($options['theme_color'] == $theme_color_key): ?>
							<option selected="selected" value="<?php echo $theme_color_key; ?>"><?php echo $theme_color_val; ?></option>
<?php else: ?>
							<option value="<?php echo $theme_color_key; ?>"><?php echo $theme_color_val; ?></option>
<?php endif; ?>
<?php endforeach; ?>
						</select>
					</td>
				</tr>

				<tr valign="top">
					<th scope="row">サイトレイアウト</th>
					<td>
						<select name="winp_theme_options[column_position]">
<?php foreach ($column_position as $cp_key => $cp_val): ?>
<?php if ($options['column_position'] == $cp_key): ?>
							<option selected="selected" value="<?php echo $cp_key; ?>"><?php echo $cp_val; ?></option>
<?php else: ?>
							<option value="<?php echo $cp_key; ?>"><?php echo $cp_val; ?></option>
<?php endif; ?>
<?php endforeach; ?>
						</select>
					</td>
				</tr>
			</table>

			<h3 class="title">ヘッダー設定</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">タイトルをヘッダーに表示</th>
					<td>
						<select name="winp_theme_options[header_title_display]">
<?php foreach ($header_title_display as $header_title_display_key => $header_title_display_val): ?>
<?php if ($options['header_title_display'] == $header_title_display_key): ?>
							<option selected="selected" value="<?php echo $header_title_display_key; ?>"><?php echo $header_title_display_val; ?></option>
<?php else: ?>
							<option value="<?php echo $header_title_display_key; ?>"><?php echo $header_title_display_val; ?></option>
<?php endif; ?>
<?php endforeach; ?>
						</select><br>
						「表示する」に設定すると、ヘッダーの最上部にタイトルが表示されます
					</td>
				</tr>

				<tr valign="top">
					<th scope="row">サイトロゴのテキストを変更</th>
					<td>
						<input class="regular-text" name="winp_theme_options[header_logo_text]" type="text" value="<?php esc_attr_e( $options['header_logo_text'] ); ?>"><br>
						※未設定の場合は、「設定 > 一般」の「サイトのタイトル」で設定したテキストが表示されます。
					</td>
				</tr>

				<tr valign="top">
					<th scope="row">サイト説明文をヘッダーに表示</th>
					<td>
						<select name="winp_theme_options[header_desc_display]">
<?php foreach ($header_desc_display as $header_desc_display_key => $header_desc_display_val): ?>
<?php if ($options['header_desc_display'] == $header_desc_display_key): ?>
							<option selected="selected" value="<?php echo $header_desc_display_key; ?>"><?php echo $header_desc_display_val; ?></option>
<?php else: ?>
							<option value="<?php echo $header_desc_display_key; ?>"><?php echo $header_desc_display_val; ?></option>
<?php endif; ?>
<?php endforeach; ?>
						</select><br>
						「表示する」に設定すると、<a href="<?php echo admin_url('/'); ?>options-general.php">一般設定</a>の「キャッチフレーズ」に設定した説明文をヘッダー右側(PC)に表示します
					</td>
				</tr>

				<tr valign="top">
					<th scope="row">パン屑リスト表示</th>
					<td>
						<select name="winp_theme_options[breadcrumb_display]">
<?php foreach ($breadcrumb_display as $breadcrumb_display_key => $breadcrumb_display_val): ?>
<?php if ($options['breadcrumb_display'] == $breadcrumb_display_key): ?>
							<option selected="selected" value="<?php echo $breadcrumb_display_key; ?>"><?php echo $breadcrumb_display_val; ?></option>
<?php else: ?>
							<option value="<?php echo $breadcrumb_display_key; ?>"><?php echo $breadcrumb_display_val; ?></option>
<?php endif; ?>
<?php endforeach; ?>
						</select>
					</td>
				</tr>
			</table>

			<h3 class="title">フッター設定</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">コピーライト</th>
					<td>
						Copyright © <input class="regular-text" name="winp_theme_options[copyright]" type="text" value="<?php esc_attr_e( $options['copyright'] ); ?>"> All Rights Reserved.
					</td>
				</tr>

			</table>

			<h3 class="title">トップページ設定</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">トップページに表示する<br>「投稿」の件数</th>
					<td>
						<select name="winp_theme_options[home_post_count]">
<?php foreach ($home_post_count as $home_post_count_key => $home_post_count_val): ?>
<?php if ($options['home_post_count'] == $home_post_count_key): ?>
							<option selected="selected" value="<?php echo $home_post_count_key; ?>"><?php echo $home_post_count_val; ?></option>
<?php elseif (empty($options['home_post_count']) && 5 == $home_post_count_key): ?>
							<option selected="selected" value="<?php echo $home_post_count_key; ?>"><?php echo $home_post_count_val; ?></option>
<?php else: ?>
							<option value="<?php echo $home_post_count_key; ?>"><?php echo $home_post_count_val; ?></option>
<?php endif; ?>
<?php endforeach; ?>
						</select>
					</td>
				</tr>
			</table>

			<h3 class="title">SNSボタン設定</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">SNSボタンの表示位置</th>
					<td>
						<ul style="margin:3px 0;">
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_position][]" value="contents_t" <?php if (is_array($options['sns_btn_position']) && in_array('contents_t', $options['sns_btn_position'])) echo 'checked'; ?>> メインコンテンツ上部</label></li>
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_position][]" value="contents_b" <?php if (is_array($options['sns_btn_position']) && in_array('contents_b', $options['sns_btn_position'])) echo 'checked'; ?>> メインコンテンツ下部</label></li>
						</ul>
					</td>
				</tr>

				<tr valign="top">
					<th scope="row">表示するSNSボタン</th>
					<td>
						<ul style="margin:3px 0;">
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_type][]" value="facebook" <?php if (is_array($options['sns_btn_type']) && in_array('facebook', $options['sns_btn_type'])) echo 'checked'; ?>> Facebook</label></li>
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_type][]" value="twitter" <?php if (is_array($options['sns_btn_type']) && in_array('twitter', $options['sns_btn_type'])) echo 'checked'; ?>> twitter</label></li>
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_type][]" value="google_plusone" <?php if (is_array($options['sns_btn_type']) && in_array('google_plusone', $options['sns_btn_type'])) echo 'checked'; ?>> Google+</label></li>
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_type][]" value="hatena" <?php if (is_array($options['sns_btn_type']) && in_array('hatena', $options['sns_btn_type'])) echo 'checked'; ?>> はてなブックマーク</label></li>
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_type][]" value="line" <?php if (is_array($options['sns_btn_type']) && in_array('line', $options['sns_btn_type'])) echo 'checked'; ?>> LINEで送る</label></li>
							<li style="display:inline-block;padding-right:10px;" autocomplete="off"><label><input type="checkbox" name="winp_theme_options[sns_btn_type][]" value="pocket" <?php if (is_array($options['sns_btn_type']) && in_array('pocket', $options['sns_btn_type'])) echo 'checked'; ?>> Pocket</label></li>
						</ul>
					</td>
				</tr>
			</table>

			<h3 class="title">解析タグ設定</h3>
			<table class="form-table">
				<tr valign="top">
					<td>
						<code>&lt;head&gt;&lt;/head&gt;</code>に設定する解析タグ
						<textarea rows="10" name="winp_theme_options[analyze_tag_header]" style="width:100%"><?php esc_attr_e( $options['analyze_tag_header'] ); ?></textarea>
					</td>
					<td>
						<code>&lt;body&gt;&lt;/body&gt;</code>に設定する解析タグ
						<textarea rows="10" name="winp_theme_options[analyze_tag_footer]" style="width:100%"><?php esc_attr_e( $options['analyze_tag_footer'] ); ?></textarea>
					</td>
			</table>

			<?php submit_button(); ?>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function theme_options_validate( $input ) {

	return $input;
}
